//+------------------------------------------------------------------+
//|                                                 VanessaFX 30.mq4 |
//|                               Copyright  2006, Taylor Stockwell |
//|                                               stockwet@yahoo.com |
//+------------------------------------------------------------------+
#property copyright "Copyright  2006, Taylor Stockwell"
#property link      "stockwet@yahoo.com"

/*
Version: 1.1
Developed: 1/19/2007

Notes, etc.
This expert produces signals when the VanessaFX 30m Advanced signal is seen on a chart. It
must be attached to a 30m chart.

Updates:
- 1/22/2007: Added Sound Alert Feature
*/

//=============== external inputs
extern bool Send_Email = true;
extern bool Sound_Alarm = true;




//=============== global vars
int signalBar;
int lastBars;
int v0=1;
int v1=2;
int v2=3;

//===========================  Get Values Functions  ============================
int aodir()
{
   int cursig;
   double ao0 = aoVal(v0);
   double ao1 = aoVal(v1);

   // Get cur bar color
   if(ao0 > ao1) cursig = 1;
   else if(ao0 < ao1) cursig = 0;
   return(cursig);
}

int psdir()
{
   int cursig;
   double ps0 = psarVal(v0);   
   if(ps0 < Low[v0]) cursig = 1;
   else if(ps0 > High[v0]) cursig = 0;
   
   return(cursig);
}


double psarVal(int shift)
{
  double val = iSAR(NULL,0,0.02,0.2,shift);
  return(val);
}

double aoVal(int shift)
{
  double val = iAO(NULL,0,shift);
  return(val);
}

//===========================  Check Crossings  ============================
bool pscrossSig()
{
   string presig, cursig;
   bool cross = false;
   double ps0 = psarVal(v0);
   double ps1 = psarVal(v1);
   
   if(psdir() == 1) cursig="up";
   else if(psdir() == 0) cursig = "dn";
   //if(ps0 > High[0]) cursig = "up";
   //else if(ps0 < Low[0]) cursig = "dn";
   
   if(ps1 < High[v1]) presig = "up";
   else if(ps1 > Low[v1]) presig = "dn";
   
   if(presig != cursig) cross = true;
   else if(presig == cursig) cross = false;
   
   return(cross);  
   
}

bool aocrossSig()
{
   string presig, cursig;
   bool cross = false;
   //double ao0 = aoVal(0);
   double ao1 = aoVal(v1);
   double ao2 = aoVal(v2);

   //Get last bar color
   if(ao1 > ao2) presig = "up";
   else if(ao1 < ao2) presig = "dn";
   
   if(aodir() == 1) cursig = "up";
   else if(aodir() == 0) cursig = "dn";
   // Get cur bar color
   //if(ao0 > ao1) cursig = "up";
   //else if(ao0 < ao1) cursig = "dn";
   
   if(presig != cursig) cross = true;
   else if(presig == cursig) cross = false;
   
   return(cross);  
   
}


void sendAlert()
{
   if(Send_Email == true)
   {
   SendMail("VanessaFX 30M Alert - Primary", "The SAR and Awesome Oscillator have reversed and lined up on "+Symbol()+
      ". This may confirm a setup or be a prelude to a trade.");
   }
}

void soundAlarm()
{
   if(Sound_Alarm == true)
   {
   Alert("The SAR and Awesome Oscillator have reversed and lined up on "+Symbol()+
      ". This may confirm a setup or be a prelude to a trade.");
   }
}


bool checkBar()
{
   bool barOK;
  if (lastBars != Bars) barOK = true;
  else barOK = false;

  return(barOK);
}

//=============== function: init
int init()
  {
   lastBars = Bars;
   signalBar = 0;
   return(0);
  }

//=============== function: deinit
int deinit()
  {

   return(0);
  }

//=============== function: start
int start()
  {

   if(checkBar() == true)
   {
      
      if(signalBar != Bars)
      {
      if((aocrossSig() == true || pscrossSig() == true) && psdir() == aodir())
         {
         sendAlert();    
         soundAlarm();  
         signalBar = Bars;
         }
      }
   lastBars = Bars;
   }
   
   /* Comments for testing
   double ao0 = aoVal(v0);
   double ao1 = aoVal(v1);
   double ao2 = aoVal(v2);
   string aoC, aoC2;
   if(ao0 >ao1) aoC="Green";
   else if(ao1 > ao0) aoC="Red";
   if(ao1 >ao2) aoC2="Green";
   else if(ao2 > ao1) aoC2="Red";
   
   Comment("Current AO Bar: "+aoC+
   "\nLast AO Bar: "+aoC2+
   "\nPSAR Dir: "+psdir()+
   "\nAO Dir: "+aodir()+
   "\nSigBar/CurBar/LastBars: "+signalBar+"/"+Bars+"/"+lastBars+   
   "\nPSAR Val: "+psarVal(v0)+
   "\nH/L: "+High[v0]+"/"+Low[v0]);
   */
   return(0);
  }

